@@ -802,6 +802,8 @@ class Utilities:
                 layoutOnly = True
             elif obj.parent.getRole() == pyatspi.ROLE_TABLE:
                 layoutOnly = self.isLayoutOnly(obj.parent)
+        elif role == pyatspi.ROLE_SECTION:
+            layoutOnly = True
         elif role == pyatspi.ROLE_FILLER:
             layoutOnly = True
         elif role == pyatspi.ROLE_SCROLL_PANE:
@@ -871,7 +873,31 @@ class Utilities:
 
         return readOnly
 
-    def isSameObject(self, obj1, obj2):
+    def _hasSamePath(self, obj1, obj2):
+        path1 = pyatspi.utils.getPath(obj1)
+        path2 = pyatspi.utils.getPath(obj2)
+        if len(path1) != len(path2):
+            return False
+
+        # The first item in all paths, even valid ones, is -1.
+        path1 = path1[1:]
+        path2 = path2[1:]
+
+        # If both have invalid child indices, all bets are off.
+        if path1.count(-1) and path2.count(-1):
+            return False
+
+        try:
+            index = path1.index(-1)
+        except ValueError:
+            try:
+                index = path2.index(-1)
+            except ValueError:
+                index = len(path2)
+
+        return path1[0:index] == path2[0:index]
+
+    def isSameObject(self, obj1, obj2, comparePaths=False):
         if (obj1 == obj2):
             return True
         elif (not obj1) or (not obj2):
@@ -880,6 +906,8 @@ class Utilities:
         try:
             if (obj1.name != obj2.name) or (obj1.getRole() != obj2.getRole()):
                 return False
+            if comparePaths and self._hasSamePath(obj1, obj2):
+                return True
             else:
                 # Comparing the extents of objects which claim to be different
                 # addresses both managed descendants and implementations which
@@ -2674,6 +2702,9 @@ class Utilities:
             debug.printException(debug.LEVEL_WARNING)
             return ""
 
+    def getLineContentsAtOffset(self, obj, offset, layoutMode=True):
+        return []
+
     def getObjectsFromEOCs(self, obj, offset=None, boundary=None):
         """Breaks the string containing a mixture of text and embedded object
         characters into a list of (obj, startOffset, endOffset, string) tuples.
@@ -2733,3 +2764,20 @@ class Utilities:
 
     def hasLongDesc(self, obj):
         return False
+
+    def headingLevel(self, obj):
+        level = 0
+
+        if obj is None:
+            return level
+
+        if obj.getRole() == pyatspi.ROLE_HEADING:
+            attributes = obj.getAttributes()
+            if attributes is None:
+                return level
+            for attribute in attributes:
+                if attribute.startswith("level:"):
+                    level = int(attribute.split(":")[1])
+                    break
+
+        return level
